@@ -406,10 +406,18 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>&amp;Change Passphrase…</source>
         <translation type="unfinished">&amp;Muuda Salasõna...</translation>
     </message>
+    <message>
+        <source>Sign &amp;message…</source>
+        <translation type="unfinished">Allkirjuta &amp;sõnum...</translation>
+    </message>
     <message>
         <source>Sign messages with your Bitcoin addresses to prove you own them</source>
         <translation type="unfinished">Omandi tõestamiseks allkirjasta sõnumid oma Bitcoini aadressiga</translation>
     </message>
+    <message>
+        <source>&amp;Verify message…</source>
+        <translation type="unfinished">&amp;Kinnita sõnum...</translation>
+    </message>
     <message>
         <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
         <translation type="unfinished">Kinnita sõnumid kindlustamaks et need allkirjastati määratud Bitcoini aadressiga</translation>
@@ -489,14 +497,48 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Open Wallet</source>
         <translation type="unfinished">Ava Rahakott</translation>
     </message>
+    <message>
+        <source>Open a wallet</source>
+        <translation type="unfinished">Ava Rahakott</translation>
+    </message>
+    <message>
+        <source>Close wallet</source>
+        <translation type="unfinished">Sulge rahakott</translation>
+    </message>
+    <message>
+        <source>Restore Wallet…</source>
+        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
+        <translation type="unfinished">Taasta Rahakoti...</translation>
+    </message>
+    <message>
+        <source>Restore a wallet from a backup file</source>
+        <extracomment>Status tip for Restore Wallet menu item</extracomment>
+        <translation type="unfinished">Taasta rahakoti varukoopiafailist</translation>
+    </message>
+    <message>
+        <source>Close all wallets</source>
+        <translation type="unfinished">Sulge rkõik rahakotid</translation>
+    </message>
+    <message>
+        <source>Migrate Wallet</source>
+        <translation type="unfinished">Migreeri rahakott</translation>
+    </message>
     <message>
         <source>&amp;Window</source>
         <translation type="unfinished">&amp;Aken</translation>
     </message>
+    <message>
+        <source>Main Window</source>
+        <translation type="unfinished">Pea Aken</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation type="unfinished">%1 klient</translation>
     </message>
+    <message>
+        <source>&amp;Hide</source>
+        <translation type="unfinished">&amp;Peida</translation>
+    </message>
     <message numerus="yes">
         <source>%n active connection(s) to Bitcoin network.</source>
         <extracomment>A substring of the tooltip.</extracomment>
@@ -505,6 +547,10 @@ Signing is only possible with addresses of the type 'legacy'.</source>
             <numerusform />
         </translation>
     </message>
+    <message>
+        <source>Error creating wallet</source>
+        <translation type="unfinished">Viga rahakoti loomisel</translation>
+    </message>
     <message>
         <source>Error: %1</source>
         <translation type="unfinished">Tõrge %1</translation>
@@ -647,6 +693,13 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <translation type="unfinished">(vahetusraha)</translation>
     </message>
 </context>
+<context>
+    <name>MigrateWalletActivity</name>
+    <message>
+        <source>Migrate Wallet</source>
+        <translation type="unfinished">Migreeri rahakott</translation>
+    </message>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
@@ -655,6 +708,17 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <translation type="unfinished">Ava Rahakott</translation>
     </message>
     </context>
+<context>
+    <name>WalletController</name>
+    <message>
+        <source>Close wallet</source>
+        <translation type="unfinished">Sulge rahakott</translation>
+    </message>
+    <message>
+        <source>Close all wallets</source>
+        <translation type="unfinished">Sulge rkõik rahakotid</translation>
+    </message>
+    </context>
 <context>
     <name>CreateWalletDialog</name>
     <message>
